﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2010 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Windows.Forms;
using HeuristicLab.MainForm;
using HeuristicLab.MainForm.WindowsForms;
using HeuristicLab.Problems.DataAnalysis.Symbolic;
using HeuristicLab.Problems.DataAnalysis.MultiVariate.TimeSeriesPrognosis.Symbolic;

namespace HeuristicLab.Problems.DataAnalysis.MultiVariate.TimeSeriesPrognosis.Views {
  [View("Simplified Symbolic Time Series Prognosis Model View")]
  [Content(typeof(SymbolicTimeSeriesPrognosisModel))]
  public partial class SimplifiedSymbolicTimeSeriesPrognosisModelView : AsynchronousContentView {
    public SimplifiedSymbolicTimeSeriesPrognosisModelView()
      : base() {
      InitializeComponent();
    }

    public new SymbolicTimeSeriesPrognosisModel Content {
      get { return (SymbolicTimeSeriesPrognosisModel)base.Content; }
      set { base.Content = value; }
    }

    protected override void OnContentChanged() {
      base.OnContentChanged();
      if (Content != null)
        UpdateTreeChart();
      else
        viewHost.Content = null;
    }

    private void UpdateTreeChart() {
      var simplifier = new SymbolicSimplifier();
      var simplifiedTree = simplifier.Simplify(Content.SymbolicExpressionTree);
      viewHost.Content = simplifiedTree;
    }
  }
}
